@@ -20,11 +20,19 @@ from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import (
     ChimeSdkMeetingConfigurationTypeDef,
+    ConcatenationSinkTypeDef,
+    ConcatenationSourceTypeDef,
     CreateMediaCapturePipelineResponseTypeDef,
+    CreateMediaConcatenationPipelineResponseTypeDef,
+    CreateMediaLiveConnectorPipelineResponseTypeDef,
     EmptyResponseMetadataTypeDef,
     GetMediaCapturePipelineResponseTypeDef,
+    GetMediaPipelineResponseTypeDef,
     ListMediaCapturePipelinesResponseTypeDef,
+    ListMediaPipelinesResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    LiveConnectorSinkConfigurationTypeDef,
+    LiveConnectorSourceConfigurationTypeDef,
     TagTypeDef,
 )
 
@@ -102,22 +110,60 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
         Tags: Sequence[TagTypeDef] = ...
     ) -> CreateMediaCapturePipelineResponseTypeDef:
         """
-        Creates a media capture pipeline.
+        Creates a media pipeline.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.create_media_capture_pipeline)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#create_media_capture_pipeline)
         """
 
+    def create_media_concatenation_pipeline(
+        self,
+        *,
+        Sources: Sequence[ConcatenationSourceTypeDef],
+        Sinks: Sequence[ConcatenationSinkTypeDef],
+        ClientRequestToken: str = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> CreateMediaConcatenationPipelineResponseTypeDef:
+        """
+        Creates a media concatenation pipeline.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.create_media_concatenation_pipeline)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#create_media_concatenation_pipeline)
+        """
+
+    def create_media_live_connector_pipeline(
+        self,
+        *,
+        Sources: Sequence[LiveConnectorSourceConfigurationTypeDef],
+        Sinks: Sequence[LiveConnectorSinkConfigurationTypeDef],
+        ClientRequestToken: str = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> CreateMediaLiveConnectorPipelineResponseTypeDef:
+        """
+        Creates a streaming media pipeline in an Amazon Chime SDK meeting.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.create_media_live_connector_pipeline)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#create_media_live_connector_pipeline)
+        """
+
     def delete_media_capture_pipeline(
         self, *, MediaPipelineId: str
     ) -> EmptyResponseMetadataTypeDef:
         """
-        Deletes the media capture pipeline.
+        Deletes the media pipeline.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.delete_media_capture_pipeline)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#delete_media_capture_pipeline)
         """
 
+    def delete_media_pipeline(self, *, MediaPipelineId: str) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes the media pipeline.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.delete_media_pipeline)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#delete_media_pipeline)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -136,25 +182,43 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
         self, *, MediaPipelineId: str
     ) -> GetMediaCapturePipelineResponseTypeDef:
         """
-        Gets an existing media capture pipeline.
+        Gets an existing media pipeline.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.get_media_capture_pipeline)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#get_media_capture_pipeline)
         """
 
+    def get_media_pipeline(self, *, MediaPipelineId: str) -> GetMediaPipelineResponseTypeDef:
+        """
+        Gets an existing media pipeline.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.get_media_pipeline)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#get_media_pipeline)
+        """
+
     def list_media_capture_pipelines(
         self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListMediaCapturePipelinesResponseTypeDef:
         """
-        Returns a list of media capture pipelines.
+        Returns a list of media pipelines.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.list_media_capture_pipelines)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#list_media_capture_pipelines)
         """
 
+    def list_media_pipelines(
+        self, *, NextToken: str = ..., MaxResults: int = ...
+    ) -> ListMediaPipelinesResponseTypeDef:
+        """
+        Returns a list of media pipelines.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.list_media_pipelines)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#list_media_pipelines)
+        """
+
     def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
         """
-        Lists the tags applied to an Amazon Chime SDK media capture pipeline.
+        Lists the tags available for a media pipeline.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#list_tags_for_resource)
@@ -162,8 +226,7 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
 
     def tag_resource(self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
-        Applies the specified tags to the specified Amazon Chime SDK media capture
-        pipeline.
+        The ARN of the media pipeline that you want to tag.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.tag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#tag_resource)
@@ -171,8 +234,7 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
 
     def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
-        Removes the specified tags from the specified Amazon Chime SDK media capture
-        pipeline.
+        Removes any tags from a media pipeline.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.untag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#untag_resource)
