@@ -6,9 +6,9 @@ Type annotations for chime-sdk-media-pipelines service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_chime_sdk_media_pipelines.literals import ArtifactsStateType
+    from mypy_boto3_chime_sdk_media_pipelines.literals import ArtifactsConcatenationStateType
 
-    data: ArtifactsStateType = "Disabled"
+    data: ArtifactsConcatenationStateType = "Disabled"
     ```
 """
 import sys
@@ -20,12 +20,24 @@ else:
 
 
 __all__ = (
+    "ArtifactsConcatenationStateType",
     "ArtifactsStateType",
+    "AudioArtifactsConcatenationStateType",
+    "AudioChannelsOptionType",
     "AudioMuxTypeType",
+    "ConcatenationSinkTypeType",
+    "ConcatenationSourceTypeType",
     "ContentMuxTypeType",
+    "ContentShareLayoutOptionType",
+    "LayoutOptionType",
+    "LiveConnectorMuxTypeType",
+    "LiveConnectorSinkTypeType",
+    "LiveConnectorSourceTypeType",
     "MediaPipelineSinkTypeType",
     "MediaPipelineSourceTypeType",
     "MediaPipelineStatusType",
+    "PresenterPositionType",
+    "ResolutionOptionType",
     "VideoMuxTypeType",
     "ChimeSDKMediaPipelinesServiceName",
     "ServiceName",
@@ -34,12 +46,24 @@ __all__ = (
 )
 
 
+ArtifactsConcatenationStateType = Literal["Disabled", "Enabled"]
 ArtifactsStateType = Literal["Disabled", "Enabled"]
-AudioMuxTypeType = Literal["AudioOnly", "AudioWithActiveSpeakerVideo"]
+AudioArtifactsConcatenationStateType = Literal["Enabled"]
+AudioChannelsOptionType = Literal["Mono", "Stereo"]
+AudioMuxTypeType = Literal["AudioOnly", "AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
+ConcatenationSinkTypeType = Literal["S3Bucket"]
+ConcatenationSourceTypeType = Literal["MediaCapturePipeline"]
 ContentMuxTypeType = Literal["ContentOnly"]
+ContentShareLayoutOptionType = Literal["Horizontal", "PresenterOnly", "Vertical"]
+LayoutOptionType = Literal["GridView"]
+LiveConnectorMuxTypeType = Literal["AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
+LiveConnectorSinkTypeType = Literal["RTMP"]
+LiveConnectorSourceTypeType = Literal["ChimeSdkMeeting"]
 MediaPipelineSinkTypeType = Literal["S3Bucket"]
 MediaPipelineSourceTypeType = Literal["ChimeSdkMeeting"]
 MediaPipelineStatusType = Literal["Failed", "InProgress", "Initializing", "Stopped", "Stopping"]
+PresenterPositionType = Literal["BottomLeft", "BottomRight", "TopLeft", "TopRight"]
+ResolutionOptionType = Literal["FHD", "HD"]
 VideoMuxTypeType = Literal["VideoOnly"]
 ChimeSDKMediaPipelinesServiceName = Literal["chime-sdk-media-pipelines"]
 ServiceName = Literal[
@@ -72,6 +96,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -217,6 +242,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
@@ -270,6 +296,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
